@@ -589,7 +589,7 @@ rev_list_view_style_set (GtkWidget *widget,
 
 	gtk_tree_view_column_set_min_width (priv->emblem_column,
 					    priv->emblem_size * 3 +
-					    2 * widget->style->xthickness);
+					    2 * gtk_widget_get_style (widget)->xthickness);
 
 	GTK_WIDGET_CLASS (giggle_rev_list_view_parent_class)->style_set (widget, prev_style);
 }
@@ -675,13 +675,20 @@ giggle_rev_list_view_class_init (GiggleRevListViewClass *class)
 
 static gboolean
 revision_property_matches (GiggleRevision *revision,
-			   const gchar    *property,
-			   const gchar    *search_term)
+                           const gchar    *property,
+                           const gchar    *search_term)
 {
-	gboolean  match;
-	gchar    *str, *casefold_str;
+	GiggleAuthor *author;
+	gboolean      match;
+	gchar        *str, *casefold_str;
 
-	g_object_get (revision, property, &str, NULL);
+	if (g_strcmp0 ("author", property) == 0) {
+		g_object_get (revision, "author", &author, NULL);
+		g_object_get (author, "name", &str, NULL);
+		g_object_unref (author);
+	} else if (g_strcmp0 ("sha", property) == 0) {
+		g_object_get (revision, "sha", &str, NULL);
+	}
 	casefold_str = g_utf8_casefold (str, -1);
 	match = strstr (casefold_str, search_term) != NULL;
 
@@ -1459,25 +1466,21 @@ rev_list_view_cell_data_author_func (GtkCellLayout   *layout,
 				     GtkTreeIter     *iter,
 				     gpointer         data)
 {
-	GiggleRevListViewPriv *priv;
-	GiggleRevision         *revision;
-	const gchar            *author = NULL;
+	GiggleAuthor   *author = NULL;
+	const char     *name = NULL;
+	GiggleRevision *revision;
 
-	priv = GET_PRIV (data);
+	gtk_tree_model_get (model, iter, COL_OBJECT, &revision, -1);
 
-	gtk_tree_model_get (model, iter,
-			    COL_OBJECT, &revision,
-			    -1);
-
-	if (revision) {
+	if (revision)
 		author = giggle_revision_get_author (revision);
-	}
+	if (author)
+		name = giggle_author_get_name (author);
 
-	g_object_set (cell, "text", author, NULL);
+	g_object_set (cell, "text", name, NULL);
 
-	if (revision) {
+	if (revision)
 		g_object_unref (revision);
-	}
 }
 
 static gchar *
@@ -1660,7 +1663,7 @@ giggle_rev_list_view_init (GiggleRevListView *rev_list_view)
 	GtkActionEntry menu_items [] = {
 		{ "Commit",         NULL,                 N_("Commit"),         NULL, NULL, G_CALLBACK (rev_list_view_commit) },
 		{ "CreateBranch",   NULL,                 N_("Create _Branch"), NULL, NULL, G_CALLBACK (rev_list_view_create_branch) },
-		{ "CreateTag",      "stock_add-bookmark", N_("Create _Tag"),    NULL, NULL, G_CALLBACK (rev_list_view_create_tag) },
+		{ "CreateTag",      "bookmark-new",       N_("Create _Tag"),    NULL, NULL, G_CALLBACK (rev_list_view_create_tag) },
 		{ "CreatePatch",    NULL,                 N_("Create _Patch"),  NULL, NULL, G_CALLBACK (rev_list_view_create_patch) },
 	};
 
@@ -1685,7 +1688,7 @@ giggle_rev_list_view_init (GiggleRevListView *rev_list_view)
 	GtkCellRenderer       *cell;
 
 	priv = GET_PRIV (rev_list_view);
-	font_size = pango_font_description_get_size (GTK_WIDGET (rev_list_view)->style->font_desc);
+	font_size = pango_font_description_get_size (gtk_widget_get_style (GTK_WIDGET (rev_list_view))->font_desc);
 	font_size = PANGO_PIXELS (font_size);
 
 	/* yes, it's a hack */
@@ -1918,6 +1921,7 @@ giggle_rev_list_view_set_selection (GiggleRevListView *list,
 	GtkTreeSelection *selection;
 	GiggleRevision   *revision;
 	GtkTreeModel     *model;
+	GtkTreePath      *path;
 	GtkTreeIter       iter;
 	GList            *l;
 
@@ -1935,6 +1939,17 @@ giggle_rev_list_view_set_selection (GiggleRevListView *list,
 			l = g_list_find_custom (revisions, revision, giggle_revision_compare);
 
 			if (l) {
+				if (!count) {
+					path = gtk_tree_model_get_path (model, &iter);
+
+					gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW (list),
+								      path, NULL, TRUE, 0.5, 0.0);
+					gtk_tree_view_set_cursor (GTK_TREE_VIEW (list),
+								  path, NULL, FALSE);
+
+					gtk_tree_path_free (path);
+				}
+
 				gtk_tree_selection_select_iter (selection, &iter);
 				revisions = g_list_delete_link (revisions, l);
 				count += 1;
