@@ -21,10 +21,8 @@
 #ifndef __GIGGLE_VIEW_HISTORY_H__
 #define __GIGGLE_VIEW_HISTORY_H__
 
-#include <glib-object.h>
-#include <gtk/gtk.h>
-
-#include "giggle-view.h"
+#include <libgiggle/giggle-revision.h>
+#include <libgiggle/giggle-view.h>
 
 G_BEGIN_DECLS
 
@@ -35,28 +33,28 @@ G_BEGIN_DECLS
 #define GIGGLE_IS_VIEW_HISTORY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GIGGLE_TYPE_VIEW_HISTORY))
 #define GIGGLE_VIEW_HISTORY_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GIGGLE_TYPE_VIEW_HISTORY, GiggleViewHistoryClass))
 
-typedef struct GiggleViewHistory      GiggleViewHistory;
-typedef struct GiggleViewHistoryClass GiggleViewHistoryClass;
+typedef struct _GiggleViewHistory      GiggleViewHistory;
+typedef struct _GiggleViewHistoryClass GiggleViewHistoryClass;
+typedef struct _GiggleViewHistoryPriv  GiggleViewHistoryPriv;
 
-struct GiggleViewHistory {
+struct _GiggleViewHistory {
 	GiggleView parent_instance;
+
+	GiggleViewHistoryPriv *priv;
 };
 
-struct GiggleViewHistoryClass {
+struct _GiggleViewHistoryClass {
 	GiggleViewClass parent_class;
 };
 
 GType              giggle_view_history_get_type          (void);
-GtkWidget *        giggle_view_history_new               (void);
+GtkWidget *        giggle_view_history_new               (GtkUIManager      *manager);
 
-void               giggle_view_history_set_compact_mode  (GiggleViewHistory *view,
-							  gboolean           compact_mode);
-gboolean           giggle_view_history_get_compact_mode  (GiggleViewHistory *view);
-
-void               giggle_view_history_set_file_list_visible (GiggleViewHistory *view,
-							      gboolean           visible);
-gboolean           giggle_view_history_get_file_list_visible (GiggleViewHistory *view);
+void               giggle_view_history_set_graph_visible (GiggleViewHistory *view,
+							  gboolean           visible);
 
+gboolean           giggle_view_history_select            (GiggleViewHistory *view,
+							  GiggleRevision    *revision);
 
 G_END_DECLS
 
